Oriole-Service
==============

[![Join project](https://badges.gitter.im/zhouxiaoxiang/oriole-service.svg)](https://gitter.im/oriole-service/Lobby?utm_source=share-link&utm_medium=link&utm_campaign=share-link) [![Let's go](https://travis-ci.org/zhouxiaoxiang/oriole-service.svg?branch=master)](https://travis-ci.org/zhouxiaoxiang/oriole-service)

**Rapidly create services.**

软件平台的搭建框架，更快，更好，更高。

Prerequisites 系统软件
----------------------

-   python3
-   mongodb
-   mysql
-   rabbitmq
-   redis

Install 安装
------------

    pip install oriole-service

Test 测试
---------

    o t

![](https://github.com/zhouxiaoxiang/oriole-service/raw/master/docs/test.gif)

Run 启动
--------

    o r <service>

![](https://github.com/zhouxiaoxiang/oriole-service/raw/master/docs/run.gif)

Halt 停止
---------

    o h <service>

Document 文档化
---------------

    o d

![](https://github.com/zhouxiaoxiang/oriole-service/raw/master/docs/doc.gif)

Check 检查平台所有服务
----------------------

![](https://github.com/zhouxiaoxiang/oriole-service/raw/master/docs/check_service.gif)
